@@ -1,11 +1,13 @@
-require 'common_models/models/devices/gazebo/entity'
-require 'common_models/models/services/position'
-require 'common_models/models/services/gps'
+# frozen_string_literal: true
+
+require "common_models/models/devices/gazebo/entity"
+require "common_models/models/services/position"
+require "common_models/models/services/gps"
 
 module CommonModels
     module Devices
         module Gazebo
-            device_type 'GPS' do
+            device_type "GPS" do
                 provides Entity
                 provides Services::Position
                 provides Services::GPS
@@ -13,4 +15,3 @@ module CommonModels
         end
     end
 end
-
