@@ -1,11 +1,12 @@
-require 'common_models/models/devices/gazebo/entity'
+# frozen_string_literal: true
+
+require "common_models/models/devices/gazebo/entity"
 module CommonModels
     module Devices
         module Gazebo
-            device_type 'Underwater' do
+            device_type "Underwater" do
                 provides Entity
             end
         end
     end
 end
-
