@@ -1,8 +1,9 @@
+# frozen_string_literal: true
+
 class OroGen::Stereo::Task
     # Additional information to allow for the transformer's automatic
     # configuration
     transformer do
-        associate_frame_to_ports 'left_camera', 'distance_frame'
+        associate_frame_to_ports "left_camera", "distance_frame"
     end
 end
-
