@@ -1,17 +1,18 @@
-require 'common_models/models/blueprints/sensors'
+# frozen_string_literal: true
 
-Dev::Sensors.device_type 'Stim300' do
+require "common_models/models/blueprints/sensors"
+
+Dev::Sensors.device_type "Stim300" do
     provides Base::CalibratedIMUSensorsSrv
 end
 
 class OroGen::Stim300::Task
-    driver_for Dev::Sensors::Stim300, :as => 'driver'
+    driver_for Dev::Sensors::Stim300, as: "driver"
 
     # Additional information to allow for the transformer's automatic
     # configuration
     transformer do
         associate_frame_to_ports "stim300", "calibrated_sensors"
-	associate_frame_to_ports "stim300", "incremental_velocity"
+        associate_frame_to_ports "stim300", "incremental_velocity"
     end
 end
-
