@@ -1,5 +1,7 @@
-require 'common_models/models/blueprints/timestamping'
-require 'common_models/models/blueprints/devices'
+# frozen_string_literal: true
+
+require "common_models/models/blueprints/timestamping"
+require "common_models/models/blueprints/devices"
 
 class OroGen::XsensImu::Task
     # Additional information to allow for the transformer's automatic
@@ -8,8 +10,7 @@ class OroGen::XsensImu::Task
         associate_frame_to_ports "imu", "calibrated_sensors"
         transform_output "orientation_samples", "imu" => "world"
     end
-    
-    driver_for Dev::Sensors::XsensAHRS, :as => 'driver'
-    provides Base::TimestampInputSrv, 'timestamps' => 'hard_timestamps', :as => 'timestamps'
-end
 
+    driver_for Dev::Sensors::XsensAHRS, as: "driver"
+    provides Base::TimestampInputSrv, "timestamps" => "hard_timestamps", :as => "timestamps"
+end
