@@ -1,7 +1,9 @@
+# frozen_string_literal: true
+
 module CommonModels
     module Services
         # Abstract data service that every component that has a controlled
         # system role in a control loop should provide
-        data_service_type 'ControlledSystem'
+        data_service_type "ControlledSystem"
     end
 end
