@@ -1,6 +1,8 @@
-import_types_from 'base'
-require 'common_models/models/services/pose'
-require 'common_models/models/services/global_position'
+# frozen_string_literal: true
+
+import_types_from "base"
+require "common_models/models/services/pose"
+require "common_models/models/services/global_position"
 
 module CommonModels
     module Services
@@ -10,9 +12,9 @@ module CommonModels
         #
         # It is typically a pose estimator which fuses a global position measurement
         # such as GPS
-        data_service_type 'GlobalPose' do
+        data_service_type "GlobalPose" do
             provides Pose
-            provides GlobalPosition, 'position_samples' => 'pose_samples'
+            provides GlobalPosition, "position_samples" => "pose_samples"
         end
     end
 end
