@@ -1,4 +1,6 @@
-import_types_from 'base'
+# frozen_string_literal: true
+
+import_types_from "base"
 
 module CommonModels
     module Services
@@ -6,8 +8,8 @@ module CommonModels
         #
         # This is common in underwater systems, where the distance to ground can be
         # measured directly
-        data_service_type 'GroundDistance' do
-            output_port 'distance', '/base/samples/RigidBodyState'
+        data_service_type "GroundDistance" do
+            output_port "distance", "/base/samples/RigidBodyState"
         end
     end
 end
