@@ -1,4 +1,6 @@
-require 'common_models/models/devices/input/graupner/mc20'
+# frozen_string_literal: true
+
+require "common_models/models/devices/input/graupner/mc20"
 
 module CommonModels
     module Devices
