@@ -1,4 +1,6 @@
-using_task_library 'canbus'
+# frozen_string_literal: true
+
+using_task_library "canbus"
 
 module OroGen
     module Canbus
@@ -14,15 +16,14 @@ module OroGen
                     end
                 end
                 it "calls the watch operation for each attached device" do
-                    dev = syskit_stub_attached_device(CommonModels::Devices::Bus::CAN, as: 'dev')
+                    dev = syskit_stub_attached_device(CommonModels::Devices::Bus::CAN, as: "dev")
                     dev.period(0.1)
                     dev.can_id(0x01, 0x11)
                     dev_task = syskit_deploy(dev)
                     bus_task = dev_task.children.first
                     syskit_start_execution_agents(bus_task)
-                    flexmock(bus_task.orocos_task).should_receive(:watch).once.
-                        with('dev', 0x01, 0x11)
                     syskit_configure(bus_task)
+                    assert_equal [["dev", 0x1, 0x11]], bus_task.orocos_task.stub_configured_watches
                 end
             end
         end
@@ -31,4 +32,3 @@ module OroGen
         end
     end
 end
-
