@@ -1,4 +1,6 @@
-using_task_library 'gps'
+# frozen_string_literal: true
+
+using_task_library "gps"
 
 module OroGen::Gps
     describe BaseTask do
@@ -9,7 +11,7 @@ module OroGen::Gps
 
         it "should set the UTM local origin on the task if it is set on Conf" do
             origin = Conf.utm_local_origin = Eigen::Vector3.new(1, 2, 3)
-            device = syskit_stub_device(CommonModels::Devices::GPS::Generic, using: GPSDTask, as: 'dev')
+            device = syskit_stub_device(CommonModels::Devices::GPS::Generic, using: GPSDTask, as: "dev")
             task = syskit_stub_deploy_and_configure(device)
             assert_equal origin, task.orocos_task.origin
         end
@@ -20,7 +22,7 @@ module OroGen::Gps
 
         it "should set the UTM local origin on the task if it is set on Conf" do
             origin = Conf.utm_local_origin = Eigen::Vector3.new(1, 2, 3)
-            device = syskit_stub_device(CommonModels::Devices::GPS::MB500, using: MB500Task, as: 'dev')
+            device = syskit_stub_device(CommonModels::Devices::GPS::MB500, using: MB500Task, as: "dev")
             task = syskit_stub_deploy_and_configure(device)
             assert_equal origin, task.orocos_task.origin
         end
